import api from "./utils/api";

// 获取当前时间戳
function getCurrentTimestamp() {
  return Date.now();
}

// 获取缓存时间戳（如果没有缓存则返回0）
function getCacheTimestamp() {
  try {
    var value = wx.getStorageSync('cache_timestamp');
    if (value) {
      return parseInt(value);
    }
  } catch (e) {
    console.error('获取缓存时间戳失败', e);
  }
  return 0;
}

// 设置缓存时间戳为当前时间戳
function setCacheTimestamp(timestamp) {
  try {
    wx.setStorageSync('cache_timestamp', timestamp.toString());
  } catch (e) {
    console.error('设置缓存时间戳失败', e);
  }
}

// 清除指定名称的缓存
function clearSpecificCache(key) {
  try {
    wx.removeStorageSync(key);
    console.log('缓存 ' + key + ' 已清除');
  } catch (e) {
    console.error('清除缓存失败', e);
  }
}

// 监测缓存是否超过一天，如果超过则清除缓存
function checkCache() {
  var currentTimestamp = getCurrentTimestamp();
  var cacheTimestamp = getCacheTimestamp();
  if (currentTimestamp - cacheTimestamp >= 3 * 60 * 60 * 1000) {
    clearSpecificCache('shareMD');
    setCacheTimestamp(currentTimestamp);
  }
}

App({
  onLaunch: function () {
    const updateManager = wx.getUpdateManager();
    updateManager.onCheckForUpdate(function (res) {
      if (res.hasUpdate) {
        updateManager.onUpdateReady(function () {
          wx.showModal({
            title: '更新提示',
            content: '新版本已经准备好，是否重启应用？',
            success: function (res) {
              if (res.confirm) {
                updateManager.applyUpdate();
              }
            }
          });
        });
        updateManager.onUpdateFailed(function () {
          wx.showModal({
            title: '更新失败',
            content: '新版本下载失败，请重启应用以获取最新版本。',
            showCancel: false
          });
        });
      }
    });
    checkCache();
  },
  globalData: {
    imgUrl: [],
  },
  api,
})
