// 引入缓存工具
const Cache = require('../../utils/cache.js');
Page({
  data: {
    columns: [[], []],
    isLoading: false,
  },
  onLoad() {
    this.getSortslist();
  },

  getSortslist() {
    if (this.data.isLoading) return;
    this.setData({ isLoading: true });
    getApp()
      .api.getSortslist({})
      .then((res) => {
        if (res.code === 0) {
          const sorts = res.data.sorts;
          const formattedData = this.formatSorts(sorts);
          const columns = this.allocateColumns(formattedData);
          this.setData({
            columns,
            isLoading: false,
          });
        } else {
          wx.showToast({
            title: '加载失败',
            icon: 'none',
          });
        }
      })
      .catch(() => {
        wx.showToast({
          title: '加载失败',
          icon: 'none',
        });
        this.setData({ isLoading: false });
      });
  },

  formatSorts(sorts) {
    let result = [];
    sorts.forEach((sort) => {
      result.push({
        sid: sort.sid,
        sortname: sort.sortname,
        imgUrl: sort.sortimg,
      });
      if (sort.children && sort.children.length > 0) {
        sort.children.forEach((child) => {
          result.push({
            sid: child.sid,
            sortname: child.sortname,
            imgUrl: child.sortimg,
          });
        });
      }
    });
    return result;
  },

  allocateColumns(data) {
    let columns = [[], []]; 
    let columnHeights = [0, 0];
    data.forEach((item) => {
      const estimatedHeight = 200;
      const targetColumn = columnHeights[0] <= columnHeights[1] ? 0 : 1;
      columns[targetColumn].push(item);
      columnHeights[targetColumn] += estimatedHeight;
    });
    return columns;
  },
  setNavigationBarColor() {
    const themeColor = Cache.get('themeColor') || '#406Eff';
    const textColor = Cache.get('textColor') || '#ffffff';
    this.setData({
      themeColor,
      textColor,
    });
    wx.setNavigationBarColor({
      frontColor: textColor,
      backgroundColor: themeColor,
      animation: {
        duration: 400,
        timingFunc: 'easeIn',
      },
    });
  },
});
